@@ -21,17 +21,14 @@ import (
 	"testing"
 	"time"
 
-	tb "github.com/tektoncd/pipeline/internal/builder/v1alpha1"
 	"github.com/tektoncd/pipeline/pkg/apis/pipeline/v1alpha1"
 	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"knative.dev/pkg/apis"
+	duckv1beta1 "knative.dev/pkg/apis/duck/v1beta1"
 	rtesting "knative.dev/pkg/reconciler/testing"
 )
 
-const (
-	waitNamespace = "wait"
-)
-
 var (
 	success = apis.Condition{Type: apis.ConditionSucceeded, Status: corev1.ConditionTrue}
 	failure = apis.Condition{Type: apis.ConditionSucceeded, Status: corev1.ConditionFalse}
@@ -39,30 +36,27 @@ var (
 
 func TestWaitForTaskRunStateSucceed(t *testing.T) {
 	d := Data{
-		TaskRuns: []*v1alpha1.TaskRun{
-			tb.TaskRun("foo",
-				tb.TaskRunNamespace(waitNamespace),
-				tb.TaskRunStatus(
-					tb.StatusCondition(success),
-				)),
-		},
+		TaskRuns: []*v1alpha1.TaskRun{{
+			ObjectMeta: metav1.ObjectMeta{Name: "foo"},
+			Status: v1alpha1.TaskRunStatus{Status: duckv1beta1.Status{
+				Conditions: []apis.Condition{success},
+			}},
+		}},
 	}
 	c, cancel := fakeClients(t, d)
 	defer cancel()
-	err := WaitForTaskRunState(c, "foo", Succeed("foo"), "TestTaskRunSucceed")
-	if err != nil {
+	if err := WaitForTaskRunState(c, "foo", Succeed("foo"), "TestTaskRunSucceed"); err != nil {
 		t.Fatal(err)
 	}
 }
 func TestWaitForTaskRunStateFailed(t *testing.T) {
 	d := Data{
-		TaskRuns: []*v1alpha1.TaskRun{
-			tb.TaskRun("foo",
-				tb.TaskRunNamespace(waitNamespace),
-				tb.TaskRunStatus(
-					tb.StatusCondition(failure),
-				)),
-		},
+		TaskRuns: []*v1alpha1.TaskRun{{
+			ObjectMeta: metav1.ObjectMeta{Name: "foo"},
+			Status: v1alpha1.TaskRunStatus{Status: duckv1beta1.Status{
+				Conditions: []apis.Condition{failure},
+			}},
+		}},
 	}
 	c, cancel := fakeClients(t, d)
 	defer cancel()
@@ -74,11 +68,12 @@ func TestWaitForTaskRunStateFailed(t *testing.T) {
 
 func TestWaitForPipelineRunStateSucceed(t *testing.T) {
 	d := Data{
-		PipelineRuns: []*v1alpha1.PipelineRun{
-			tb.PipelineRun("bar", tb.PipelineRunNamespace(waitNamespace), tb.PipelineRunStatus(
-				tb.PipelineRunStatusCondition(success),
-			)),
-		},
+		PipelineRuns: []*v1alpha1.PipelineRun{{
+			ObjectMeta: metav1.ObjectMeta{Name: "bar"},
+			Status: v1alpha1.PipelineRunStatus{Status: duckv1beta1.Status{
+				Conditions: []apis.Condition{success},
+			}},
+		}},
 	}
 	c, cancel := fakeClients(t, d)
 	defer cancel()
@@ -90,11 +85,12 @@ func TestWaitForPipelineRunStateSucceed(t *testing.T) {
 
 func TestWaitForPipelineRunStateFailed(t *testing.T) {
 	d := Data{
-		PipelineRuns: []*v1alpha1.PipelineRun{
-			tb.PipelineRun("bar", tb.PipelineRunNamespace(waitNamespace), tb.PipelineRunStatus(
-				tb.PipelineRunStatusCondition(failure),
-			)),
-		},
+		PipelineRuns: []*v1alpha1.PipelineRun{{
+			ObjectMeta: metav1.ObjectMeta{Name: "bar"},
+			Status: v1alpha1.PipelineRunStatus{Status: duckv1beta1.Status{
+				Conditions: []apis.Condition{failure},
+			}},
+		}},
 	}
 	c, cancel := fakeClients(t, d)
 	defer cancel()
@@ -108,12 +104,11 @@ func fakeClients(t *testing.T, d Data) (*clients, func()) {
 	ctx, _ := rtesting.SetupFakeContext(t)
 	ctx, cancel := context.WithCancel(ctx)
 	fakeClients, _ := SeedTestData(t, ctx, d)
-	// 	c.KubeClient = fakeClients.Kube
 	return &clients{
-		PipelineClient:         fakeClients.Pipeline.TektonV1alpha1().Pipelines(waitNamespace),
-		PipelineResourceClient: fakeClients.Resource.TektonV1alpha1().PipelineResources(waitNamespace),
-		PipelineRunClient:      fakeClients.Pipeline.TektonV1alpha1().PipelineRuns(waitNamespace),
-		TaskClient:             fakeClients.Pipeline.TektonV1alpha1().Tasks(waitNamespace),
-		TaskRunClient:          fakeClients.Pipeline.TektonV1alpha1().TaskRuns(waitNamespace),
+		PipelineClient:         fakeClients.Pipeline.TektonV1alpha1().Pipelines(""),
+		PipelineResourceClient: fakeClients.Resource.TektonV1alpha1().PipelineResources(""),
+		PipelineRunClient:      fakeClients.Pipeline.TektonV1alpha1().PipelineRuns(""),
+		TaskClient:             fakeClients.Pipeline.TektonV1alpha1().Tasks(""),
+		TaskRunClient:          fakeClients.Pipeline.TektonV1alpha1().TaskRuns(""),
 	}, cancel
 }
